@@ -1,7 +1,11 @@
 from django.contrib.auth.forms import PasswordResetForm, SetPasswordForm
 from django.contrib.auth import authenticate, login, logout, get_user_model
 from django.contrib.auth.tokens import default_token_generator
-from django.utils.http import urlsafe_base64_decode
+try:
+    from django.utils.http import urlsafe_base64_decode as uid_decoder
+except:
+    # make compatible with django 1.5
+    from django.utils.http import base36_to_int as uid_decoder
 from django.conf import settings
 
 from rest_framework import status
@@ -129,11 +133,12 @@ class Register(LoggedOutRESTAPIView, GenericAPIView):
     """
 
     serializer_class = UserRegistrationSerializer
+    profile_serializer_class = UserRegistrationProfileSerializer
 
     def post(self, request):
         # Create serializers with request.DATA
         serializer = self.serializer_class(data=request.DATA)
-        profile_serializer = UserRegistrationProfileSerializer(
+        profile_serializer = self.profile_serializer_class(
             data=request.DATA)
 
         if serializer.is_valid() and profile_serializer.is_valid():
@@ -144,7 +149,10 @@ class Register(LoggedOutRESTAPIView, GenericAPIView):
             # TODO: Make this customizable backend via settings.
             # Call RESTRegistrationView().register to create new Django User
             # and UserProfile models
-            RESTRegistrationView().register(request, **serializer.data)
+            data = serializer.data.copy()
+            data.update(profile_serializer.data)
+
+            RESTRegistrationView().register(request, **data)
 
             # Return the User object with Created HTTP status
             return Response(UserDetailsSerializer(serializer.data).data,
@@ -249,26 +257,26 @@ class PasswordResetConfirm(LoggedOutRESTAPIView, GenericAPIView):
     Password reset e-mail link is confirmed, therefore this resets the user's password.
 
     Accepts the following POST parameters: new_password1, new_password2
-    Accepts the following Django URL arguments: token, uidb64
+    Accepts the following Django URL arguments: token, uid
     Returns the success/fail message.
     """
 
     serializer_class = SetPasswordSerializer
 
-    def post(self, request, uidb64=None, token=None):
+    def post(self, request, uid=None, token=None):
         # Get the UserModel
         UserModel = get_user_model()
 
         # Decode the uidb64 to uid to get User object
         try:
-            uid = urlsafe_base64_decode(uidb64)
+            uid = uid_decoder(uid)
             user = UserModel._default_manager.get(pk=uid)
         except (TypeError, ValueError, OverflowError, UserModel.DoesNotExist):
             user = None
 
         # If we get the User object
         if user:
-            serializer = self.serializer_class(data=request.DATA)
+            serializer = self.serializer_class(data=request.DATA, user=user)
 
             if serializer.is_valid():
                 # Construct SetPasswordForm instance
@@ -295,7 +303,7 @@ class PasswordResetConfirm(LoggedOutRESTAPIView, GenericAPIView):
                                 status=status.HTTP_400_BAD_REQUEST)
 
         else:
-            return Response({"errors": "Couldn\'t find the user from uidb64."}, status=status.HTTP_400_BAD_REQUEST)
+            return Response({"errors": "Couldn\'t find the user from uid."}, status=status.HTTP_400_BAD_REQUEST)
 
 
 class VerifyEmail(LoggedOutRESTAPIView, GenericAPIView):
